import requests
import aiohttp

async def search_text_async(query, max_results=10):
    """
    Search for a query using a text search API.

    Args:
        query (str): The search query.
        max_results (int): The maximum number of results to fetch.

    Returns:
        list: A list of search results, where each result is a dictionary containing 'title', 'href', and 'body'.
    """
    base_url = "https://cerina-search.vercel.app/search"
    params = {
        "q": query,
        "max_results": max_results
    }

    async with aiohttp.ClientSession() as session:
        async with session.get(base_url, params=params) as response:
            if response.status == 200:
                data = await response.json()
                return data.get("results", [])
            else:
                raise Exception(f"Failed to fetch results. Status code: {response.status}")


def search_text(query, max_results=10):
    """
    Search for a query using a text search API.

    Args:
        query (str): The search query.
        max_results (int): The maximum number of results to fetch.

    Returns:
        list: A list of search results, where each result is a dictionary containing 'title', 'href', and 'body'.
    """
    base_url = "https://cerina-search.vercel.app/search"
    params = {
        "q": query,
        "max_results": max_results
    }

    response = requests.get(base_url, params=params)

    if response.status_code == 200:
        data = response.json()
        return data.get("results", [])
    else:
        raise Exception(f"Failed to fetch results. Status code: {response.status_code}")
    

def print_text_result(results):
    """
    Print the search results.

    Args:
        results (list): List of search results.
    """
    for index, result in enumerate(results, start=1):
        print(f"Result {index}:")
        for key, value in result.items():
            print(f"  {key.capitalize()}: {value}")
        print()



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="cerina",
    version="0.2.6",
    description='Next-gen Sync & Async AI agents with 100+ functionalities',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(),
    install_requires=[
        "aiohttp",
        "nest_asyncio",
        "requests",
        "pytest",
        "webdriver-manager",
        "selenium",
    ],
)


import aiohttp
from typing import Optional
from .gpt import Completion

class PromptOptimizer:
    def __init__(self, model: Optional[str] = None, token: Optional[str] = None):
        self.completion = Completion(model=model, token=token)

    async def optimize_prompt(self, prompt: str) -> str:
        """
        Optimize the given prompt using the GPT API.

        Args:
            prompt (str): The prompt to optimize.

        Returns:
            str: The optimized prompt.
        """
        optimized_prompt = await self.create_async(prompt)
        return optimized_prompt

    async def create_async(self, prompt: str) -> str:
        """
        Create a response using the GPT API.

        Args:
            prompt (str): The prompt to send to the GPT API.

        Returns:
            str: The response from the GPT API.
        """
        return await self.completion.create_async(prompt)